%global project tempest

Summary:        OpenStack Integration Test Suite (Tempest)
Name:           openstack-%{project}
Version:        33.0.0
Release:        3%{?dist}
License:        ASL 2.0
Url:            https://launchpad.net/tempest
Source0:        http://tarballs.openstack.org/tempest/tempest-%{version}.tar.gz

BuildArch:      noarch

BuildRequires: git-core python3-oslo-config python3-pbr python3-setuptools python3-devel
BuildRequires: python3-importlib-metadata python3-defusedxml

Requires:       python3-tempest = %{version}-%{release}

%description
This is a set of integration tests to be run against a live OpenStack cluster.\
Tempest has batteries of tests for OpenStack API validation, Scenarios, and \
other specific tests useful in validating an OpenStack deployment.

%package -n    python3-%{project}
Summary:       Tempest Python library
Requires: python3-subunit python3-unittest2 >= 1.1.0 python3-yaml >= 3.12
Requires: python3-stevedore >= 1.20.0 python3-stestr python3-testtools python3-urllib3
Requires: python3-prettytable >= 0.7.1 python3-six >= 1.10.0
Requires: python3-paramiko >= 2.7.0 python3-pbr >= 2.0.0
Requires: python3-oslo-utils >= 3.33.0 python3-os-testr >= 0.8.0
Requires: python3-oslo-log >= 3.36.0 python3-oslo-serialization >= 2.18.0
Requires: python3-oslo-concurrency >= 3.26.0 python3-oslo-config >= 5.2.0
Requires: python3-jsonschema >= 3.2.0 python3-netaddr >= 0.7.18
Requires: python3-debtcollector >= 1.2.0 python3-fixtures >= 3.0.0
Requires: python3-cliff >= 2.8.0

%description -n python3-%{project}
This package contains the tempest python library.

%package -n     python3-%{project}-tests
Summary:        Python Tempest tests
BuildRequires:  python3-mock python3-oslotest python3-subunit python3-oslo-log
BuildRequires:  python3-jsonschema python3-urllib3 python3-oslo-concurrency
BuildRequires:  python3-paramiko python3-cliff python3-pycodestyle python3-os-testr
BuildRequires:  python3-stestr python3-PyYAML
Requires:       python3-tempest = %{version}-%{release}
Requires:       python3-mock
Requires:       python3-oslotest

%description -n python3-%{project}-tests
This package provides testcase for %{name}.

%prep
%autosetup -n tempest-%{version} -p1
rm -rf *requirements.txt

RPMLINT_OFFENDERS="tempest/cmd/list_plugins.py \
tempest/cmd/cleanup.py \
tempest/cmd/cleanup_service.py \
tempest/cmd/verify_tempest_config.py \
tempest/cmd/account_generator.py \
tempest/lib/cmd/skip_tracker.py \
tempest/lib/cmd/check_uuid.py"
sed -i '1{/^#!/d}' $RPMLINT_OFFENDERS
chmod u=rw,go=r $RPMLINT_OFFENDERS

%build
%{py3_build}

%install
%{py3_install}

mkdir -p %{buildroot}%{_sysconfdir}/%{project}/
oslo-config-generator --config-file tempest/cmd/config-generator.tempest.conf \
    --output-file %{buildroot}%{_sysconfdir}/%{project}/tempest.conf

mkdir -p %{buildroot}/etc/tempest
mv %{buildroot}/usr/etc/tempest/* %{buildroot}/etc/tempest

%check
export OS_TEST_PATH='./tempest/tests'
export PATH=$PATH:%{buildroot}/usr/bin
export PYTHONPATH=$PWD
rm -f $OS_TEST_PATH/test_hacking.py
# This may fail on koji. Disable it for now.
rm -f $OS_TEST_PATH/test_waiters.py
PYTHON=%{__python3} stestr --test-path $OS_TEST_PATH run

%files
%license LICENSE
%doc README.rst
%{_bindir}/tempest
%{_bindir}/check-uuid
%{_bindir}/skip-tracker
%{_bindir}/subunit-describe-calls
%{_sysconfdir}/%{project}/*sample
%{_sysconfdir}/%{project}/*yaml
%config(noreplace) %{_sysconfdir}/%{project}/*.conf

%files -n python3-%{project}
%license LICENSE
%{python3_sitelib}/%{project}
%{python3_sitelib}/%{project}*.egg-info
%exclude %{python3_sitelib}/tempest/tests

%files -n python3-%{project}-tests
%license LICENSE
%{python3_sitelib}/tempest/tests

%changelog
* Wed Jun 11 2025 bbrucezhang <bbrucezhang@tencent.com> - 33.0.0-3
- Rebuilt for loongarch64

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 33.0.0-2
- Rebuilt for loongarch release

* Sat Oct 7 2023 Shuo Wang <abushwang@tencent.com> - 33.0.0-1
- update to 33.0.0

* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 27.0.0-4
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 27.0.0-3
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 27.0.0-2
- Rebuilt for OpenCloudOS Stream 23.05

* Thu Apr 13 2023 cunshunxia <cunshunxia@tencent.com> - 27.0.0-1
- initial build
